svn commit: r220591 - head/sys/dev/siis

Alexander Motin mav at FreeBSD.org
Wed Apr 13 06:36:23 UTC 2011


Author: mav
Date: Wed Apr 13 06:36:22 2011
New Revision: 220591
URL: http://svn.freebsd.org/changeset/base/220591

Log:
  As soon as siis_reset() doesn't waits for device readiness, but only for
  controller port readiness (that should set just after PHY ready signal),
  reduce wait time from 10s to 1s before trying more aggressive reset method.
  
  This should improve system responsibility in some failure conditions.

Modified:
  head/sys/dev/siis/siis.c

Modified: head/sys/dev/siis/siis.c
==============================================================================
--- head/sys/dev/siis/siis.c	Wed Apr 13 04:40:59 2011	(r220590)
+++ head/sys/dev/siis/siis.c	Wed Apr 13 06:36:22 2011	(r220591)
@@ -1631,9 +1631,9 @@ retry:
 		xpt_release_simq(ch->sim, TRUE);
 		return;
 	}
-	/* Wait for clearing busy status. */
-	if (siis_wait_ready(dev, 10000)) {
-		device_printf(dev, "device ready timeout\n");
+	/* Wait for port ready status. */
+	if (siis_wait_ready(dev, 1000)) {
+		device_printf(dev, "port ready timeout\n");
 		if (!retry) {
 			device_printf(dev, "trying full port reset ...\n");
 			/* Get port to the reset state. */


More information about the svn-src-all mailing list